@@ -149,6 +149,17 @@
 #   include <io.h>
 #endif
 
+/*
+ * Dynamic library handling.  These are needed for dynamically loading I/O
+ * filters and VFDs.
+ */
+#ifdef H5_HAVE_DLFCN_H
+#include <dlfcn.h>
+#endif
+#ifdef H5_HAVE_DIRENT_H
+#include <dirent.h>
+#endif
+
 
 #ifdef H5_HAVE_WIN32_API
 /* The following two defines must be before any windows headers are included */
@@ -426,6 +437,24 @@
 #define  HSSIZET_MAX  ((hssize_t)LLONG_MAX)
 #define HSSIZET_MIN  (~(HSSIZET_MAX))
 
+/*
+ * Types and max sizes for POSIX I/O.
+ * OS X (Darwin) is odd since the max I/O size does not match the types.
+ */
+#if defined(H5_HAVE_WIN32_API)
+#   define h5_posix_io_t                unsigned int
+#   define h5_posix_io_ret_t            int
+#   define H5_POSIX_MAX_IO_BYTES        INT_MAX
+#elif defined(H5_HAVE_DARWIN)
+#   define h5_posix_io_t                size_t
+#   define h5_posix_io_ret_t            ssize_t
+#   define H5_POSIX_MAX_IO_BYTES        INT_MAX
+#else
+#   define h5_posix_io_t                size_t
+#   define h5_posix_io_ret_t            ssize_t
+#   define H5_POSIX_MAX_IO_BYTES        SSIZET_MAX
+#endif
+
 /*
  * A macro to portably increment enumerated types.
  */
@@ -809,6 +838,9 @@ H5_DLL int HDfprintf (FILE *stream, const char *fmt, ...);
 #ifndef HDgetgroups
     #define HDgetgroups(Z,G)  getgroups(Z,G)
 #endif /* HDgetgroups */
+#ifndef HDgethostname
+    #define HDgethostname(N,L)    gethostname(N,L)
+#endif /* HDgetlogin */
 #ifndef HDgetlogin
     #define HDgetlogin()    getlogin()
 #endif /* HDgetlogin */
@@ -1449,19 +1481,20 @@ extern char *strdup(const char *s);
 #if defined(H5_HAVE_WINDOW_PATH)
 
 /* directory delimiter for Windows: slash and backslash are acceptable on Windows */
-#define  DIR_SLASH_SEPC     '/'
-#define  DIR_SEPC     '\\'
-#define  DIR_SEPS     "\\"
-#define CHECK_DELIMITER(SS)     ((SS == DIR_SEPC)||(SS == DIR_SLASH_SEPC))
-#define CHECK_ABSOLUTE(NAME)    ((isalpha(NAME[0])) && (NAME[1] == ':') && (CHECK_DELIMITER(NAME[2])))
-#define CHECK_ABS_DRIVE(NAME)   ((isalpha(NAME[0])) && (NAME[1] == ':'))
-#define CHECK_ABS_PATH(NAME)    (CHECK_DELIMITER(NAME[0]))
+#define H5_DIR_SLASH_SEPC       '/'
+#define H5_DIR_SEPC             '\\'
+#define H5_DIR_SEPS             "\\"
+#define H5_CHECK_DELIMITER(SS)     ((SS == H5_DIR_SEPC) || (SS == H5_DIR_SLASH_SEPC))
+#define H5_CHECK_ABSOLUTE(NAME)    ((HDisalpha(NAME[0])) && (NAME[1] == ':') && (H5_CHECK_DELIMITER(NAME[2])))
+#define H5_CHECK_ABS_DRIVE(NAME)   ((HDisalpha(NAME[0])) && (NAME[1] == ':'))
+#define H5_CHECK_ABS_PATH(NAME)    (H5_CHECK_DELIMITER(NAME[0]))
 
-#define GET_LAST_DELIMITER(NAME, ptr) {                 \
+#define H5_GET_LAST_DELIMITER(NAME, ptr) {                 \
     char        *slash, *backslash;                     \
-    slash = strrchr(NAME, DIR_SLASH_SEPC);              \
-    backslash = strrchr(NAME, DIR_SEPC);                \
-    if (backslash > slash)                              \
+                                                        \
+    slash = HDstrrchr(NAME, H5_DIR_SLASH_SEPC);         \
+    backslash = HDstrrchr(NAME, H5_DIR_SEPC);           \
+    if(backslash > slash)                               \
         (ptr = backslash);                              \
     else                                                \
         (ptr = slash);                                  \
@@ -1471,27 +1504,27 @@ extern char *strdup(const char *s);
 
 /* OpenVMS pathname: <disk name>$<partition>:[path]<file name>
  *     i.g. SYS$SYSUSERS:[LU.HDF5.SRC]H5system.c */
-#define    DIR_SEPC  ']'
-#define    DIR_SEPS  "]"
-#define         CHECK_DELIMITER(SS)             (SS == DIR_SEPC)
-#define         CHECK_ABSOLUTE(NAME)            (strrchr(NAME, ':') && strrchr(NAME, '['))
-#define   CHECK_ABS_DRIVE(NAME)           (0)
-#define   CHECK_ABS_PATH(NAME)      (0)
-#define         GET_LAST_DELIMITER(NAME, ptr)   ptr = strrchr(NAME, DIR_SEPC);
+#define H5_DIR_SEPC                     ']'
+#define H5_DIR_SEPS                     "]"
+#define H5_CHECK_DELIMITER(SS)             (SS == H5_DIR_SEPC)
+#define H5_CHECK_ABSOLUTE(NAME)            (HDstrrchr(NAME, ':') && HDstrrchr(NAME, '['))
+#define H5_CHECK_ABS_DRIVE(NAME)           (0)
+#define H5_CHECK_ABS_PATH(NAME)            (0)
+#define H5_GET_LAST_DELIMITER(NAME, ptr)   ptr = HDstrrchr(NAME, H5_DIR_SEPC);
 
 #else
 
-#define    DIR_SEPC  '/'
-#define    DIR_SEPS  "/"
-#define         CHECK_DELIMITER(SS)             (SS == DIR_SEPC)
-#define         CHECK_ABSOLUTE(NAME)            (CHECK_DELIMITER(*NAME))
-#define   CHECK_ABS_DRIVE(NAME)     (0)
-#define   CHECK_ABS_PATH(NAME)      (0)
-#define         GET_LAST_DELIMITER(NAME, ptr)   ptr = strrchr(NAME, DIR_SEPC);
+#define H5_DIR_SEPC             '/'
+#define H5_DIR_SEPS             "/"
+#define H5_CHECK_DELIMITER(SS)     (SS == H5_DIR_SEPC)
+#define H5_CHECK_ABSOLUTE(NAME)    (H5_CHECK_DELIMITER(*NAME))
+#define H5_CHECK_ABS_DRIVE(NAME)   (0)
+#define H5_CHECK_ABS_PATH(NAME)    (0)
+#define H5_GET_LAST_DELIMITER(NAME, ptr)   ptr = HDstrrchr(NAME, H5_DIR_SEPC);
 
 #endif
 
-#define   COLON_SEPC  ':'
+#define   H5_COLON_SEPC  ':'
 
 
 /* Use FUNC to safely handle variations of C99 __func__ keyword handling */
@@ -2019,7 +2052,30 @@ static herr_t    H5_INTERFACE_INIT_FUNC(void);
 #define H5_GLUE4(w,x,y,z)  w##x##y##z
 
 /* Compile-time "assert" macro */
-#define HDcompile_assert(e)     do { enum { compile_assert__ = 1 / (e) }; } while(0)
+#define HDcompile_assert(e)     ((void)sizeof(char[ !!(e) ? 1 : -1]))
+/* Variants that are correct, but generate compile-time warnings in some circumstances:
+  #define HDcompile_assert(e)     do { enum { compile_assert__ = 1 / (e) }; } while(0)
+  #define HDcompile_assert(e)     do { typedef struct { unsigned int b: (e); } x; } while(0)
+*/
+
+/* Macros for enabling/disabling particular GCC warnings */
+/* (see the following web-sites for more info:
+ *      http://www.dbp-consulting.com/tutorials/SuppressingGCCWarnings.html
+ *      http://gcc.gnu.org/onlinedocs/gcc/Diagnostic-Pragmas.html#Diagnostic-Pragmas
+ */
+/* These pragmas are only implemented usefully in gcc 4.6+ */
+#if ((__GNUC__ * 100) + __GNUC_MINOR__) >= 406
+    #define GCC_DIAG_STR(s) #s
+    #define GCC_DIAG_JOINSTR(x,y) GCC_DIAG_STR(x ## y)
+    #define GCC_DIAG_DO_PRAGMA(x) _Pragma (#x)
+    #define GCC_DIAG_PRAGMA(x) GCC_DIAG_DO_PRAGMA(GCC diagnostic x)
+
+    #define GCC_DIAG_OFF(x) GCC_DIAG_PRAGMA(push) GCC_DIAG_PRAGMA(ignored GCC_DIAG_JOINSTR(-W,x))
+    #define GCC_DIAG_ON(x) GCC_DIAG_PRAGMA(pop)
+#else
+    #define GCC_DIAG_OFF(x)
+    #define GCC_DIAG_ON(x)
+#endif
 
 /* Private functions, not part of the publicly documented API */
 H5_DLL herr_t H5_init_library(void);
@@ -2036,6 +2092,7 @@ H5_DLL int H5G_term_interface(void);
 H5_DLL int H5I_term_interface(void);
 H5_DLL int H5L_term_interface(void);
 H5_DLL int H5P_term_interface(void);
+H5_DLL int H5PL_term_interface(void);
 H5_DLL int H5R_term_interface(void);
 H5_DLL int H5S_term_interface(void);
 H5_DLL int H5T_term_interface(void);
